@@ -12,8 +12,6 @@ Several considerations are made;
      method. Arguments are packaged in _Arguments.
 """
 
-import SBstoat
-from SBstoat.namedTimeseries import NamedTimeseries, TIME, mkNamedTimeseries
 from SBstoat.timeseriesStatistic import TimeseriesStatistic
 from SBstoat._bootstrapResult import BootstrapResult
 from SBstoat.observationSynthesizer import  \
@@ -22,15 +20,9 @@ from SBstoat import _modelFitterCore as mfc
 from SBstoat import _helpers
 from SBstoat.logs import Logger
 
-import inspect
-import lmfit
 import multiprocessing
 import numpy as np
-import os
-import pandas as pd
-import random
 import sys
-import time
 import typing
 
 MAX_CHISQ_MULT = 5
@@ -62,7 +54,7 @@ class _Arguments():
         self.synthesizerClass = synthesizerClass
         self._loggerPrefix = _loggerPrefix
         self.kwargs = kwargs
-       
+
 
 ################# FUNCTIONS ####################
 def _runBootstrap(arguments:_Arguments, queue=None)->BootstrapResult:
@@ -135,7 +127,7 @@ def _runBootstrap(arguments:_Arguments, queue=None)->BootstrapResult:
             fittingSetupBlock = Logger.join(iterationBlock, "fittingSetup")
             fittingSetupGuid = logger.startBlock(fittingSetupBlock)
             newFitter = ModelFitterBootstrap(fitter.roadrunnerModel,
-                  newObservedTS,  
+                  newObservedTS,
                   fitter.parametersToFit,
                   selectedColumns=fitter.selectedColumns,
                   # Use bootstrap methods for fitting
@@ -209,24 +201,23 @@ def _runBootstrap(arguments:_Arguments, queue=None)->BootstrapResult:
             fd.close()
     if queue is None:
         return bootstrapResult
-    else:
-        queue.put(bootstrapResult)
+    queue.put(bootstrapResult)
 
 
 ##################### CLASSES #########################
 class ModelFitterBootstrap(mfc.ModelFitterCore):
 
-    def bootstrap(self, 
+    def bootstrap(self,
           # The following must be kept in sync with ModelFitterCore.__init__
-          numIteration:int=10, 
-          reportInterval:int=1000,
+          numIteration:int=None,
+          reportInterval:int=None,
           synthesizerClass=ObservationSynthesizerRandomizedResiduals,
           maxProcess:int=None,
           serializePath:str=None,
           **kwargs: dict):
         """
         Constructs a bootstrap estimate of parameter values.
-    
+
         Parameters
         ----------
         numIteration: number of bootstrap iterations
@@ -236,7 +227,7 @@ class ModelFitterBootstrap(mfc.ModelFitterCore):
         maxProcess: Maximum number of processes to use. Default: numCPU
         serializePath: Where to serialize the fitter after bootstrap
         kwargs: arguments passed to ObservationSynthesizer
-              
+
         Example
         -------
             f.bootstrap()
@@ -249,35 +240,29 @@ class ModelFitterBootstrap(mfc.ModelFitterCore):
         ----
         """
         def get(name, value):
+            if value is not None:
+                return value
+            # Handle arguments specified in constructor
             if name in self.bootstrapKwargs:
                 if self.bootstrapKwargs[name] is not None:
                     return self.bootstrapKwargs[name]
-                else:
-                    return value
-            else:
-                return value
+            # None specified
+            return None
         # Handle overrides of arguments specified in constructor
         numIteration = get("numIteration", numIteration)
         reportInterval = get("reportInterval", reportInterval)
         synthesizerClass = get("synthesizerClass", synthesizerClass)
         maxProcess = get("maxProcess", maxProcess)
         serializePath = get("serializePath", serializePath)
-        # Other initializations       
+        # Other initializations
         if maxProcess is None:
             maxProcess = multiprocessing.cpu_count()
         if self.minimizerResult is None:
             self.fitModel()
-        base_redchi = self.minimizerResult.redchi
         # Run processes
         numProcess = max(int(numIteration/ITERATION_PER_PROCESS), 1)
         numProcess = min(numProcess, maxProcess)
         numProcessIteration = int(np.ceil(numIteration/numProcess))
-        args_list = [_Arguments(self, numProcess, i,
-              numIteration=numProcessIteration,
-              reportInterval=reportInterval,
-              synthesizerClass=synthesizerClass,
-              _loggerPrefix="bootstrap",
-              **kwargs) for i in range(numProcess)]
         msg = "Running bootstrap for %d successful iterations " % numIteration
         msg += "with %d processes." % numProcess
         self.logger.activity(msg)
@@ -287,6 +272,12 @@ class ModelFitterBootstrap(mfc.ModelFitterCore):
         results = []
         # Set to False for debug so not doing multiple processes
         if True:
+            args_list = [_Arguments(self, numProcess, i,
+                  numIteration=numProcessIteration,
+                  reportInterval=reportInterval,
+                  synthesizerClass=synthesizerClass,
+                  _loggerPrefix="bootstrap",
+                  **kwargs) for i in range(numProcess)]
             for args in args_list:
                 p = multiprocessing.Process(target=_runBootstrap,
                       args=(args, queue,))
@@ -307,9 +298,15 @@ class ModelFitterBootstrap(mfc.ModelFitterCore):
                 pass
         else:
             # Keep to debug _runBootstrap single threaded
-            results = []
-            for args in args_list:
-                results.append(_runBootstrap(args))
+            thisNumProcess = 1
+            thisProcessIdx = 0
+            args = _Arguments(self, thisNumProcess, thisProcessIdx,
+                  numIteration=numIteration,
+                  reportInterval=reportInterval,
+                  synthesizerClass=synthesizerClass,
+                  _loggerPrefix="bootstrap",
+                  **kwargs)
+            results = [_runBootstrap(args)]
         if len(results) == 0:
             msg = "modelFitterBootstrap/timeout in solving model."
             msg = "\nConsider increasing per timeout."
@@ -330,36 +327,34 @@ class ModelFitterBootstrap(mfc.ModelFitterCore):
     def getParameterMeans(self)->typing.List[float]:
         """
         Returns a list of values mean values of parameters from bootstrap.
-      
+
         Return
         ------
         NamedTimeseries
-              
+
         Example
         -------
               f.getParameterMeans()
         """
         if self._checkBootstrap(isError=False):
             return self.bootstrapResult.parameterMeanDct.values()
-        else:
-            return [self.params[p].value for p in self.parametersToFit]
+        return [self.params[p].value for p in self.parametersToFit]
 
     def getParameterStds(self)->typing.List[float]:
         """
         Returns a list of values std values of parameters from bootstrap.
-      
+
         Return
         ------
         NamedTimeseries
-              
+
         Example
         -------
               f.getParameterStds()
         """
         if self._checkBootstrap(isError=False):
             return list(self.bootstrapResult.parameterStdDct.values())
-        else:
-            raise ValueError("***Must run bootstrap to get parameter stds.")
+        raise ValueError("***Must run bootstrap to get parameter stds.")
 
     def _checkBootstrap(self, isError:bool=True)->bool:
         """
@@ -369,6 +364,5 @@ class ModelFitterBootstrap(mfc.ModelFitterCore):
         if self.bootstrapResult is None:
             if isError:
                 raise ValueError("Must use bootstrap first.")
-            else:
-                return False
+            return False
         return True
