@@ -8,20 +8,14 @@ Core logic of model fitter. Does not include plots.
 """
 
 from SBstoat.namedTimeseries import NamedTimeseries, TIME, mkNamedTimeseries
-from SBstoat.observationSynthesizer import  \
-      ObservationSynthesizerRandomizedResiduals
 from SBstoat.logs import Logger
 import SBstoat.timeseriesPlotter as tp
-from SBstoat import namedTimeseries
 from SBstoat import rpickle
 
 import collections
 import copy
 import lmfit
 import numpy as np
-import pandas as pd
-import random
-import roadrunner
 import tellurium as te
 import typing
 
@@ -42,10 +36,16 @@ NULL_STR = ""
 IS_REPORT = False
 LOWER_PARAMETER_MULT = 0.95
 UPPER_PARAMETER_MULT = 0.95
+LARGE_RESIDUAL = 1000000
+
+
+_BestParameters = collections.namedtuple("_BestParameters",
+      "params rssq")  #  parameters, residuals sum of squares
+
 
 
 ##############################
-class ParameterSpecification(object):
+class ParameterSpecification():
 
     def __init__(self, lower=None, value=None, upper=None):
         self.lower = lower
@@ -55,29 +55,36 @@ class ParameterSpecification(object):
 
 class ModelFitterCore(rpickle.RPickler):
 
+    # Subclasses used in interface
+    class OptimizerMethod():
+
+        def __init__(self, method, kwargs):
+            self.method = method
+            self.kwargs = kwargs
+
+
     def __init__(self, modelSpecification, observedData,
           parametersToFit=None,
           selectedColumns=None,
-          fitterMethods=METHOD_FITTER_DEFAULTS,
+          fitterMethods=None,
           numFitRepeat=1,
-          bootstrapMethods=METHOD_BOOTSTRAP_DEFAULTS,
+          bootstrapMethods=None,
           parameterLowerBound=PARAMETER_LOWER_BOUND,
           parameterUpperBound=PARAMETER_UPPER_BOUND,
-          parameterDct={},
-          fittedDataTransformDct={},
+          parameterDct=None,
+          fittedDataTransformDct=None,
           logger=Logger(),
           isPlot=True,
           _loggerPrefix="",
           # The following must be kept in sync with ModelFitterBootstrap.bootstrap
-          numIteration:int=10, 
+          numIteration:int=10,
           reportInterval:int=1000,
-          synthesizerClass=ObservationSynthesizerRandomizedResiduals,
           maxProcess:int=None,
           serializePath:str=None,
           ):
         """
-        Constructs estimates of parameter values. 
-    
+        Constructs estimates of parameter values.
+
         Parameters
         ----------
         modelSpecification: ExtendedRoadRunner/str
@@ -103,16 +110,14 @@ class ModelFitterCore(rpickle.RPickler):
                    input: NamedTimeseries
                    output: array for the values of the column
         logger: Logger
-        fitterMethods: str/list-str
+        fitterMethods: str/list-str/list-OptimizerMethod
             method used for minimization in fitModel
         numFitRepeat: int
             number of times fitting is repeated for a method
-        bootstrapMethods: str/list-str
+        bootstrapMethods: str/list-str/list-OptimizerMethod
             method used for minimization in bootstrap
         numIteration: number of bootstrap iterations
         reportInterval: number of iterations between progress reports
-        synthesizerClass: object that synthesizes new observations
-            Must subclass ObservationSynthesizer
         maxProcess: Maximum number of processes to use. Default: numCPU
         serializePath: Where to serialize the fitter after bootstrap
 
@@ -139,10 +144,10 @@ class ModelFitterCore(rpickle.RPickler):
                   maxProcess=maxProcess,
                   serializePath=serializePath,
                   )
-            self.parameterDct = self._updateParameterDct(parameterDct)
+            self.parameterDct = ModelFitterCore._updateParameterDct(parameterDct)
             self._numFitRepeat = numFitRepeat
             if self.parametersToFit is None:
-                self.parametersToFit = [p for p in self.parameterDct.keys()]
+                self.parametersToFit = list(self.parameterDct.keys())
             self.observedTS = observedData
             if self.observedTS is not None:
                 self.observedTS = mkNamedTimeseries(observedData)
@@ -152,16 +157,15 @@ class ModelFitterCore(rpickle.RPickler):
             if (selectedColumns is None) and (self.observedTS is not None):
                 selectedColumns = self.observedTS.colnames
             self.selectedColumns = selectedColumns
-            # Construct array of non-nan observed values
-            self._observedArr = self.observedTS[self.selectedColumns].flatten()
+            if self.observedTS is not None:
+                self._observedArr = self.observedTS[self.selectedColumns].flatten()
+            else:
+                self._observedArr = None
             # Other internal state
-            self._fitterMethods = fitterMethods
-            if isinstance(self._fitterMethods, str):
-                if self._fitterMethods == METHOD_BOTH:
-                    self._fitterMethods = METHOD_FITTER_DEFAULTS
-                else:
-                    self._fitterMethods = [self._fitterMethods]
-            self._bootstrapMethods = bootstrapMethods
+            self._fitterMethods = self._makeMethods(fitterMethods,
+                  METHOD_FITTER_DEFAULTS)
+            self._bootstrapMethods = self._makeMethods(bootstrapMethods,
+                  METHOD_BOOTSTRAP_DEFAULTS)
             if isinstance(self._bootstrapMethods, str):
                 self._bootstrapMethods = [self._bootstrapMethods]
             self._isPlot = isPlot
@@ -178,26 +182,243 @@ class ModelFitterCore(rpickle.RPickler):
             self.bootstrapResult = None  # Result from bootstrapping
             # Validation checks
             self._validateFittedDataTransformDct()
+            self._bestParameters = _BestParameters(rssq=None, params=None)
         else:
             pass
-    
+
+    def _makeMethods(self, methods, default):
+        """
+        Creates a method dictionary.
+
+        Parameters
+        ----------
+        methods: str/list-str/dict
+            method used for minimization in fitModel
+            dict: key-method, value-optional parameters
+
+        Returns
+        -------
+        list-OptimizerMethod
+            key: method name
+            value: dict of optional parameters
+        """
+        if methods is None:
+            methods = default
+        if isinstance(methods, str):
+            if methods == METHOD_BOTH:
+                methods = METHOD_FITTER_DEFAULTS
+            else:
+                methods = [methods]
+        if isinstance(methods, list):
+            if isinstance(methods[0], str):
+                results = [ModelFitterCore.OptimizerMethod(method=m, kwargs={})
+                      for m in methods]
+            else:
+                results = methods
+        else:
+            raise RuntimeError("Must be a list")
+        trues = [isinstance(m, ModelFitterCore.OptimizerMethod) for m in results]
+        if not all(trues):
+            raise ValueError("Invalid methods: %s" % str(methods))
+        return results
+
+
+    @classmethod
+    def mkParameters(cls, parameterDct:dict=None,
+          parametersToFit:list=None,
+          logger:Logger=Logger(),
+          lowerBound:float=PARAMETER_LOWER_BOUND,
+          upperBound:float=PARAMETER_UPPER_BOUND)->lmfit.Parameters:
+        """
+        Constructs lmfit parameters based on specifications.
+
+        Parameters
+        ----------
+        parameterDct: key=name, value=ParameterSpecification
+        parametersToFit: list of parameters to fit
+        logger: error logger
+        lowerBound: lower value of range for parameters
+        upperBound: upper value of range for parameters
+
+        Returns
+        -------
+        lmfit.Parameters
+        """
+        def get(value, base_value, multiplier):
+            if value is not None:
+                return value
+            return base_value*multiplier
+        #
+        if (parametersToFit is None) and (parameterDct is None):
+            raise RuntimeError("Must specify one of these parameters.")
+        if parameterDct is None:
+            parameterDct = {}
+        if parametersToFit is None:
+            parametersToFit = parameterDct.keys()
+        if logger is None:
+            logger = logger()
+        params = lmfit.Parameters()
+        for parameterName in parametersToFit:
+            if parameterName in parameterDct.keys():
+                specification = parameterDct[parameterName]
+                value = get(specification.value, specification.value, 1.0)
+                if value > 0:
+                    lower_factor = LOWER_PARAMETER_MULT
+                    upper_factor = UPPER_PARAMETER_MULT
+                else:
+                    upper_factor = UPPER_PARAMETER_MULT
+                    lower_factor = LOWER_PARAMETER_MULT
+                lower = get(specification.lower, specification.value,
+                      lower_factor)
+                upper = get(specification.upper, specification.value,
+                      upper_factor)
+                if np.isclose(lower - upper, 0):
+                    upper = 0.0001
+                try:
+                    params.add(parameterName, value=value, min=lower, max=upper)
+                except Exception as err:
+                    msg = "modelFitterCore/mkParameters parameterName %s" \
+                          % parameterName
+                    logger.error(msg, err)
+            else:
+                value = np.mean([lowerBound, upperBound])
+                params.add(parameterName, value=value,
+                      min=lowerBound, max=upperBound)
+        return params
+
+    @classmethod
+    def initializeRoadrunnerModel(cls, modelSpecification):
+        """
+        Sets self.roadrunnerModel.
+
+        Parameters
+        ----------
+        modelSpecification: ExtendedRoadRunner/str
+
+        Returns
+        -------
+        ExtendedRoadRunner
+        """
+        if isinstance(modelSpecification,
+              te.roadrunner.extended_roadrunner.ExtendedRoadRunner):
+            roadrunnerModel = modelSpecification
+        elif isinstance(modelSpecification, str):
+            roadrunnerModel = te.loada(modelSpecification)
+        else:
+            msg = 'Invalid model.'
+            msg = msg + "\nA model must either be a Roadrunner model "
+            msg = msg + "an Antimony model."
+            raise ValueError(msg)
+        return roadrunnerModel
+
+    @classmethod
+    def setupModel(cls, roadrunner, parameters, logger=Logger()):
+        """
+        Sets up the model for use based on the parameter parameters
+
+        Parameters
+        ----------
+        roadrunner: ExtendedRoadRunner
+        parameters: lmfit.Parameters
+        logger Logger
+        """
+        pp = parameters.valuesdict()
+        for parameter in pp.keys():
+            try:
+                roadrunner.model[parameter] = pp[parameter]
+            except Exception as err:
+                msg = "_modelFitterCore.setupModel: Could not set value for %s"  \
+                      % parameter
+                logger.error(msg, err)
+
+    @classmethod
+    def runSimulation(cls, parameters=None,
+          roadrunner=None,
+          startTime=0,
+          endTime=5,
+          numPoint=30,
+          selectedColumns=None,
+          returnDataFrame=True,
+          _logger=Logger(),
+          _loggerPrefix="",
+          ):
+        """
+        Runs a simulation. Defaults to parameter values in the simulation.
+
+        Parameters
+       ----------
+        roadrunner: ExtendedRoadRunner/str
+            Roadrunner model
+        parameters: lmfit.Parameters
+            lmfit parameters
+        startTime: float
+            start time for the simulation
+        endTime: float
+            end time for the simulation
+        numPoint: int
+            number of points in the simulation
+        selectedColumns: list-str
+            output columns in simulation
+        returnDataFrame: bool
+            return a DataFrame
+        _logger: Logger
+        _loggerPrefix: str
+
+
+        Return
+        ------
+        NamedTimeseries (or None if fail to converge)
+        """
+        if isinstance(roadrunner, str):
+            roadrunner = cls.initializeRoadrunnerModel(roadrunner)
+        else:
+            roadrunner.reset()
+        if parameters is not None:
+            # Parameters have been specified
+            cls.setupModel(roadrunner, parameters, logger=_logger)
+        # Do the simulation
+        if selectedColumns is not None:
+            newSelectedColumns = list(selectedColumns)
+            if TIME not in newSelectedColumns:
+                newSelectedColumns.insert(0, TIME)
+            try:
+                data = roadrunner.simulate(startTime, endTime, numPoint,
+                      newSelectedColumns)
+            except Exception as err:
+                _logger.error("Roadrunner exception: ", err)
+                data = None
+        else:
+            try:
+                data = roadrunner.simulate(startTime, endTime, numPoint)
+            except Exception as err:
+                _logger.exception("Roadrunner exception: %s", err)
+                data = None
+        if data is None:
+            return data
+        fittedTS = NamedTimeseries(namedArray=data)
+        if returnDataFrame:
+            result = fittedTS.to_dataframe()
+        else:
+            result = fittedTS
+        return result
+
     @classmethod
     def rpConstruct(cls):
         """
         Overrides rpickler.rpConstruct to create a method that
         constructs an instance without arguments.
-        
+
         Returns
         -------
         Instance of cls
         """
         return cls(None, None, None)
-    
+
     def rpRevise(self):
         """
         Overrides rpickler.
         """
-        if not "logger" in self.__dict__.keys():
+        if "logger" not in self.__dict__.keys():
             self.logger = Logger()
 
     def _validateFittedDataTransformDct(self):
@@ -208,16 +429,16 @@ class ModelFitterCore(rpickle.RPickler):
                 excess = set(keySet).difference(selectedColumnsSet)
                 if len(excess) > 0:
                     msg = "Columns not in selectedColumns: %s"  % str(excess)
-                    raise ValueError(excess)
+                    raise ValueError(msg)
 
     def _transformFittedTS(self, data):
         """
         Updates the fittedTS taking into account required transformations.
- 
+
         Parameters
         ----------
         data: np.ndarray
- 
+
         Results
         ----------
         NamedTimeseries
@@ -230,18 +451,21 @@ class ModelFitterCore(rpickle.RPickler):
                 if func is not None:
                     fittedTS[column] = func(fittedTS)
         return fittedTS
-        
-    def _updateParameterDct(self, parameterDct):
+
+    @staticmethod
+    def _updateParameterDct(parameterDct):
         """
         Handles values that are tuples instead of ParameterSpecification.
         """
+        if parameterDct is None:
+            parameterDct = {}
         dct = dict(parameterDct)
         for name, value in parameterDct.items():
             if isinstance(value, tuple):
                 dct[name] = ParameterSpecification(lower=value[0],
                       upper=value[1], value=value[2])
         return dct
-        
+
     @staticmethod
     def addParameter(parameterDct: dict,
           name: str, lower: float, upper: float, value: float):
@@ -255,7 +479,7 @@ class ModelFitterCore(rpickle.RPickler):
         lower: lower range of parameter value
         upper: upper range of parameter value
         value: initial value
-        
+
         Returns
         -------
         dict
@@ -341,25 +565,17 @@ class ModelFitterCore(rpickle.RPickler):
             newModelFitter.params = self.params
         return newModelFitter
 
-    def _initializeRoadrunnerModel(self):
+    def initializeRoadRunnerModel(self):
         """
         Sets self.roadrunnerModel.
         """
-        if isinstance(self.modelSpecification,
-              te.roadrunner.extended_roadrunner.ExtendedRoadRunner):
-            self.roadrunnerModel = self.modelSpecification
-        elif isinstance(self.modelSpecification, str):
-            self.roadrunnerModel = te.loada(self.modelSpecification)
-        else:
-            msg = 'Invalid model.'
-            msg = msg + "\nA model must either be a Roadrunner model "
-            msg = msg + "an Antimony model."
-            raise ValueError(msg)
+        self.roadrunnerModel = ModelFitterCore.initializeRoadrunnerModel(
+              self.modelSpecification)
 
     def getDefaultParameterValues(self):
         """
         Obtain the original values of parameters.
-        
+
         Returns
         -------
         dict:
@@ -367,7 +583,7 @@ class ModelFitterCore(rpickle.RPickler):
             value: value of parameter
         """
         dct = {}
-        self. _initializeRoadrunnerModel()
+        self.initializeRoadRunnerModel()
         self.roadrunnerModel.reset()
         for parameterName in self.parametersToFit:
             dct[parameterName] = self.roadrunnerModel.model[parameterName]
@@ -388,61 +604,29 @@ class ModelFitterCore(rpickle.RPickler):
         ------
         NamedTimeseries
         """
-        def set(default, parameter):
+        def setValue(default, parameter):
             # Sets to default if parameter unspecified
             if parameter is None:
                 return default
-            else:
-                return parameter
-        ##V
-        block = Logger.join(self._loggerPrefix, "fitModel.simulate")
-        guid = self.logger.startBlock(block)
-        ## V
-        sub1Block = Logger.join(block, "sub1")
-        sub1Guid = self.logger.startBlock(sub1Block)
-        startTime = set(self.observedTS.start, startTime)
-        endTime = set(self.observedTS.end, endTime)
-        numPoint = set(len(self.observedTS), numPoint)
-        ##  V
-        sub1aBlock = Logger.join(sub1Block, "sub1a")
-        sub1aGuid = self.logger.startBlock(sub1aBlock)
+            return parameter
+        #
+        startTime = setValue(self.observedTS.start, startTime)
+        endTime = setValue(self.observedTS.end, endTime)
+        numPoint = setValue(len(self.observedTS), numPoint)
+        #
         if self.roadrunnerModel is None:
-            self._initializeRoadrunnerModel()
-        self.roadrunnerModel.reset()
-        ##  ^
-        self.logger.endBlock(sub1aGuid)
-        ##  V
-        sub1bBlock = Logger.join(sub1Block, "sub1b")
-        sub1bGuid = self.logger.startBlock(sub1bBlock)
-        if params is not None:
-          # Parameters have been specified
-          self._setupModel(params)
-        ##  ^
-        self.logger.endBlock(sub1bGuid)
-        # Do the simulation
-        selectedColumns = list(self.selectedColumns)
-        if not TIME in selectedColumns:
-            selectedColumns.insert(0, TIME)
-        ## ^
-        self.logger.endBlock(sub1Guid)
-        ## V
-        roadrunnerBlock = Logger.join(block, "roadrunner")
-        roadrunnerGuid = self.logger.startBlock(roadrunnerBlock)
-        data = self.roadrunnerModel.simulate(startTime, endTime, numPoint,
-              selectedColumns)
-        self.logger.endBlock(roadrunnerGuid)
-        ## ^
-        # Select the required columns
-        ## V
-        sub2Block = Logger.join(block, "sub2")
-        sub2Guid = self.logger.startBlock(sub2Block)
-        fittedTS = NamedTimeseries(namedArray=data)
-        self.logger.endBlock(sub2Guid)
-        ## ^
-        self.logger.endBlock(guid)
-        ##^
-        return fittedTS
-        
+            self.initializeRoadRunnerModel()
+        #
+        return ModelFitterCore.runSimulation(parameters=params,
+              roadrunner=self.roadrunnerModel,
+              startTime=startTime,
+              endTime=endTime,
+              numPoint=numPoint,
+              selectedColumns=self.selectedColumns,
+              _logger=self.logger,
+              _loggerPrefix=self._loggerPrefix,
+              returnDataFrame=False)
+
     def updateFittedAndResiduals(self, **kwargs)->np.ndarray:
         """
         Updates values of self.fittedTS and self.residualsTS
@@ -463,12 +647,14 @@ class ModelFitterCore(rpickle.RPickler):
         1-d ndarray of residuals
         """
         self.fittedTS = self.simulate(**kwargs)  # Updates self.fittedTS
+        residualsArr = self._residuals(self.params)
+        numRow = len(self.fittedTS)
+        numCol = len(residualsArr)//numRow
+        residualsArr = np.reshape(residualsArr, (numRow, numCol))
         cols = self.selectedColumns
         if self.residualsTS is None:
             self.residualsTS = self.observedTS.subsetColumns(cols)
-        self.residualsTS[cols] = self.observedTS[cols] - self.fittedTS[cols]
-        for col in cols:
-            self.residualsTS[col] = np.nan_to_num(self.residualsTS[col])
+        self.residualsTS[cols] = residualsArr
 
     def _residuals(self, params)->np.ndarray:
         """
@@ -481,50 +667,32 @@ class ModelFitterCore(rpickle.RPickler):
         kwargs: dict
             arguments for simulation
 
-        Instance Variables Updated
-        --------------------------
-        self.residualsTS
-
         Returns
         -------
         1-d ndarray of residuals
         """
-        block = Logger.join(self._loggerPrefix, "fitModel._residuals")
-        guid = self.logger.startBlock(block)
-        ##V
-        self.roadrunnerModel.reset()
-        self._setupModel(params)
-        #
-        roadrunnerBlock = Logger.join(block, "roadrunner")
-        roadrunnerGuid = self.logger.startBlock(roadrunnerBlock)
-        ## V
-        #
-        data = self.roadrunnerModel.simulate(
-              self.observedTS.start, self.observedTS.end,
-              len(self.observedTS),
-              self.selectedColumns)
-        ## ^
-        self.logger.endBlock(roadrunnerGuid)
-        #
-        tailBlock = Logger.join(block, "tail")
-        tailGuid = self.logger.startBlock(tailBlock)
-        ## V
-        residualsArr = self._observedArr - data.flatten()
-        residualsArr = np.nan_to_num(residualsArr)
-        ## ^
-        self.logger.endBlock(tailGuid)
-        ##^
-        self.logger.endBlock(guid)
-        #
-        # Used for detailed debugging
-        if False:
-            self.logger.details("_residuals/std(residuals): %f" % 
-                  np.std(residualsArr))
-            self.logger.details("_residuals/params: %s" % str(params))
+        data = ModelFitterCore.runSimulation(parameters=params,
+              roadrunner=self.roadrunnerModel,
+              startTime=self.observedTS.start,
+              endTime=self.observedTS.end,
+              numPoint=len(self.observedTS),
+              selectedColumns=self.selectedColumns,
+              _logger=self.logger,
+              _loggerPrefix=self._loggerPrefix,
+              returnDataFrame=False)
+        if data is None:
+            residualsArr = np.repeat(LARGE_RESIDUAL, len(self._observedArr))
+        else:
+            residualsArr = self._observedArr - data.flatten()
+            residualsArr = np.nan_to_num(residualsArr)
+        rssq = sum(residualsArr**2)
+        if (self._bestParameters.rssq is None)  \
+              or (rssq < self._bestParameters.rssq):
+            self._bestParameters = _BestParameters(
+                  params=params.copy(), rssq=rssq)
         return residualsArr
 
-    def fitModel(self, params:lmfit.Parameters=None,
-          max_nfev:int=100):
+    def fitModel(self, params:lmfit.Parameters=None, max_nfev=100):
         """
         Fits the model by adjusting values of parameters based on
         differences between simulated and provided values of
@@ -533,59 +701,65 @@ class ModelFitterCore(rpickle.RPickler):
         Parameters
         ----------
         params: starting values of parameters
-        max_nfev: maximum number of function evaluations
 
         Example
         -------
         f.fitModel()
         """
         ParameterDescriptor = collections.namedtuple("ParameterDescriptor",
-              "params method std minimizer minimizerResult")
+              "params method rssq kwargs minimizer minimizerResult")
+        MAX_NFEV = "max_nfev"
         block = Logger.join(self._loggerPrefix, "fitModel")
         guid = self.logger.startBlock(block)
-        self._initializeRoadrunnerModel()
-        if self.parametersToFit is None:
-            # Compute fit and residuals for base model
-            self.params = None
-        else:
+        self.initializeRoadRunnerModel()
+        self.params = None
+        if self.parametersToFit is not None:
             if params is None:
                 params = self.mkParams()
             # Fit the model to the data using one or more methods.
             # Choose the result with the lowest residual standard deviation
-            paramDct = {}
-            for method in self._fitterMethods:           
+            paramResults = []
+            lastExcp = None
+            for idx, optimizerMethod in enumerate(self._fitterMethods):
+                method = optimizerMethod.method
+                kwargs = optimizerMethod.kwargs
+                if MAX_NFEV not in kwargs:
+                    kwargs[MAX_NFEV] = max_nfev
                 for _ in range(self._numFitRepeat):
-                    minimizer = lmfit.Minimizer(self._residuals, params,
-                          max_nfev=max_nfev)
+                    self._bestParameters = _BestParameters(params=None, rssq=None)
+                    minimizer = lmfit.Minimizer(self._residuals, params)
                     try:
                         minimizerResult = minimizer.minimize(
-                              method=method, max_nfev=max_nfev)
+                              method=method, **kwargs)
                     except Exception as excp:
+                        lastExcp = excp
                         msg = "Error minimizing for method: %s" % method
                         self.logger.error(msg, excp)
                         continue
-                    params = minimizerResult.params
-                    std = np.std(self._residuals(params))
-                    if method in paramDct.keys():
-                        if std >= paramDct[method].std:
+                    params = self._bestParameters.params.copy()
+                    rssq = np.sum(self._residuals(params)**2)
+                    if len(paramResults) > idx:
+                        if rssq >= paramResults[idx].rssq:
                             continue
-                    paramDct[method] = ParameterDescriptor(
-                          params=params.copy(),
+                    parameterDescriptor = ParameterDescriptor(
+                          params=params,
                           method=method,
-                          std=std,
+                          rssq=rssq,
+                          kwargs=dict(kwargs),
                           minimizer=minimizer,
                           minimizerResult=minimizerResult,
                           )
-            if len(paramDct) == 0:
+                    paramResults.append(parameterDescriptor)
+            if len(paramResults) == 0:
                 msg = "*** Minimizer failed for this model and data."
-                raise ValueError(msg)
-            # Select the result that has the smallest residuals
-            sortedMethods = sorted(paramDct.keys(),
-                  key=lambda m: paramDct[m].std)
-            bestMethod = sortedMethods[0]
-            self.params = paramDct[bestMethod].params
-            self.minimizer= paramDct[bestMethod].minimizer
-            self.minimizerResult = paramDct[bestMethod].minimizerResult
+                self.logger.error(msg, lastExcp)
+            else:
+                # Select the result that has the smallest residuals
+                sortedMethods = sorted(paramResults, key=lambda r: r.rssq)
+                bestMethod = sortedMethods[0]
+                self.params = bestMethod.params
+                self.minimizer= bestMethod.minimizer
+                self.minimizerResult = bestMethod.minimizerResult
         # Ensure that residualsTS and fittedTS match the parameters
         self.updateFittedAndResiduals(params=self.params)
         self.logger.endBlock(guid)
@@ -603,23 +777,16 @@ class ModelFitterCore(rpickle.RPickler):
         self._setupModel(self.params)
         return self.roadrunnerModel
 
-    def _setupModel(self, params):
+    def _setupModel(self, parameters):
         """
         Sets up the model for use based on the parameter parameters
 
         Parameters
         ----------
-        params: lmfit.Parameters
+        parameters: lmfit.Parameters
 
         """
-        pp = params.valuesdict()
-        for parameter in self.parametersToFit:
-            try:
-                self.roadrunnerModel.model[parameter] = pp[parameter]
-            except Exception as err:
-                msg = "_modelFitterCore/_setupModel: Could not set value for %s"  \
-                      % parameter
-                self.logger.error(msg, err)
+        ModelFitterCore.setupModel(self.roadrunnerModel, parameters, logger=self.logger)
 
     def mkParams(self, parameterDct:dict=None)->lmfit.Parameters:
         """
@@ -628,46 +795,18 @@ class ModelFitterCore(rpickle.RPickler):
         Parameters
         ----------
         parameterDct: key=name, value=ParameterSpecification
-        
+
         Returns
         -------
         lmfit.Parameters
         """
-        def get(value, base_value, multiplier):
-            if value is not None:
-                return value
-            return base_value*multiplier
-        #
         if parameterDct is None:
             parameterDct = self.parameterDct
-        params = lmfit.Parameters()
-        for parameterName in self.parametersToFit:
-            if parameterName in parameterDct.keys():
-                specification = parameterDct[parameterName]
-                value = get(specification.value, specification.value, 1.0)
-                if value > 0:
-                    lower_factor = LOWER_PARAMETER_MULT
-                    upper_factor = UPPER_PARAMETER_MULT
-                else:
-                    upper_factor = UPPER_PARAMETER_MULT
-                    lower_factor = LOWER_PARAMETER_MULT
-                lower = get(specification.lower, specification.value,
-                      lower_factor)
-                upper = get(specification.upper, specification.value,
-                      upper_factor)
-                if np.isclose(lower - upper, 0):
-                    upper = 0.0001
-                try:
-                    params.add(parameterName, value=value, min=lower, max=upper)
-                except Exception as err:
-                    msg = "modelFitterCore/mkParams parameterName %s" \
-                          % parameterName
-                    self.logger.error(msg, err)
-            else:
-                value = np.mean([self.lowerBound, self.upperBound])
-                params.add(parameterName, value=value,
-                      min=self.lowerBound, max=self.upperBound)
-        return params
+        return ModelFitterCore.mkParameters(parameterDct,
+              parametersToFit=self.parametersToFit,
+              logger=self.logger,
+              lowerBound=self.lowerBound,
+              upperBound=self.upperBound)
 
     def _checkFit(self):
         if self.params is None:
@@ -703,5 +842,5 @@ class ModelFitterCore(rpickle.RPickler):
         """
         with open(path, "rb") as fd:
             fitter = rpickle.load(fd)
-        fitter._initializeRoadrunnerModel()
+        fitter.initializeRoadRunnerModel()
         return fitter
