@@ -16,12 +16,9 @@ from SBstoat import _helpers
 
 import abc
 import numpy as np
-import time
-import typing
+import pandas as pd
 
 
-# FIXME: Get same random sequence in different processes.
-#        Consider using the last digit in time.time() as a seed.
 class ObservationSynthesizer(abc.ABC):
 
 
@@ -37,9 +34,14 @@ class ObservationSynthesizer(abc.ABC):
         fittedTS: Fitted values
         residualsTS: Residual values
         """
-        self._observedTS = observedTS
-        self._fittedTS = fittedTS
-        self._residualsTS = residualsTS
+        def getTS(data):
+            if isinstance(data, pd.DataFrame):
+                return NamedTimeseries(dataframe=data)
+            return data
+        #
+        self._observedTS = getTS(observedTS)
+        self._fittedTS = getTS(fittedTS)
+        self._residualsTS = getTS(residualsTS)
         if self._observedTS is not None:
             self._observedTS = self._observedTS.copy()
         if self._fittedTS is not None:
@@ -125,7 +127,7 @@ class ObservationSynthesizerRandomizedResiduals(ObservationSynthesizer):
         for column in self.columns:
             if len(self._filteredResidualsDct[column]) == 0:
                 msg = "No residuals left after filtering."
-                msg +- " Make filter less restrictive."
+                msg += " Make filter less restrictive."
                 raise ValueError(msg)
             newObservedTS[column] += np.random.choice(
                 self._filteredResidualsDct[column], numRow, replace=True)
